"""refactor_uninfo

迁移 ID: d6e05e49f79f
父迁移: 9492159f98f7
创建时间: 2025-05-13 18:57:21.620656

"""

from __future__ import annotations

from collections.abc import Sequence
from typing import TYPE_CHECKING

import sqlalchemy as sa
from alembic import op
from nonebot import logger
from sqlalchemy.ext.automap import automap_base
from sqlalchemy.orm import Session

if TYPE_CHECKING:
    from nonebot_plugin_user.models import Bind as BindModel


revision: str = "d6e05e49f79f"
down_revision: str | Sequence[str] | None = "9492159f98f7"
branch_labels: str | Sequence[str] | None = None
depends_on: str | Sequence[str] | None = None


MAPPING = {
    "console": "Console",
    "discord": "Discord",
    "dodo": "DoDo",
    "feishu": "Feishu",
    "kaiheila": "Kaiheila",
    "qq": "QQClient",
    "qqguild": "QQAPI",
    "telegram": "Telegram",
    "unknown": "Unknown",
}

REV_MAPPING = {v: k for k, v in MAPPING.items()}


def upgrade(name: str = "") -> None:
    if name:
        return
    # ### commands auto generated by Alembic - please adjust! ###

    Base = automap_base()
    Base.prepare(op.get_bind())
    Bind: type[BindModel] = Base.classes.nonebot_plugin_user_bind

    with Session(op.get_bind()) as sess:
        binds = sess.scalars(sa.select(Bind)).all()
        for bind in binds:
            if bind.platform == "qq":
                if bind.platform_id.isdigit():
                    bind.platform = "QQClient"
                else:
                    bind.platform = "QQAPI"
            else:
                bind.platform = MAPPING.get(bind.platform, "Unknown")
        sess.add_all(binds)
        sess.commit()

    logger.info("[bind] 已成功替换平台名称")
    # ### end Alembic commands ###


def downgrade(name: str = "") -> None:
    if name:
        return
    # ### commands auto generated by Alembic - please adjust! ###
    Base = automap_base()
    Base.prepare(op.get_bind())
    Bind: type[BindModel] = Base.classes.nonebot_plugin_user_bind
    with Session(op.get_bind()) as sess:
        binds = sess.scalars(sa.select(Bind)).all()
        for bind in binds:
            bind.platform = REV_MAPPING.get(bind.platform, "unknown")
        sess.add_all(binds)
        sess.commit()
    logger.info("[bind] 已成功还原平台名称")
    # ### end Alembic commands ###
